@@ -138,7 +138,7 @@ def safepath(fspath: FsPath) -> str:
     return path_str
 
 
-def file_size(fspath: FsPath) -> int:
+def filesize(fspath: FsPath) -> int:
     """Return the size of the given file(path) in bytes
 
     Args:
@@ -1481,57 +1481,82 @@ sstring = wstr = sstr = wstring
 ljson = rjson
 sjson = wjson
 
+# module exports
 __all__ = (
     "Stdio",
     "SymlinkType",
+    "__version__",
     "chmod",
     "copy_file",
     "cp",
     "dirpath_gen",
     "dirs_gen",
     "exists",
+    "exists_async",
     "extension",
     "file_lines_gen",
-    "file_size",
     "filecmp",
     "filepath_gen",
     "filepath_mtimedelta_sec",
     "files_dirs_gen",
     "files_gen",
+    "filesize",
+    "filesize_async",
     "fspath",
-    "imports_only",
     "is_dir",
+    "is_dir_async",
     "is_file",
+    "is_file_async",
     "is_link",
+    "is_link_async",
     "isdir",
+    "isdir_async",
     "isfile",
+    "isfile_async",
     "islink",
+    "islink_async",
     "lbin",
     "lbytes",
+    "lbytes_async",
     "lbytes_gen",
+    "lbytes_gen_async",
     "listdir_gen",
     "ljson",
+    "ljson_async",
+    "lstat_async",
     "lstr",
+    "lstr_async",
     "lstring",
+    "lstring_async",
     "mkdir",
     "mkdirp",
     "path_gen",
     "rbin",
+    "rbin_async",
     "rbin_gen",
+    "rbin_gen_async",
     "rbytes",
+    "rbytes_async",
     "rbytes_gen",
+    "rbytes_gen_async",
     "rename",
     "rjson",
+    "rjson_async",
     "rm",
     "rm_gen",
     "rmdir",
     "rmfile",
     "rstr",
+    "rstr_async",
     "rstring",
+    "rstring_async",
     "safepath",
     "sbin",
+    "sbin_async",
     "sbytes",
+    "sbytes_async",
     "sbytes_gen",
+    "sbytes_gen_async",
     "scandir",
     "scandir_gen",
     "scandir_list",
@@ -1542,17 +1567,28 @@ __all__ = (
     "sep_strip",
     "shebang",
     "sjson",
+    "sjson_async",
     "sstr",
+    "sstr_async",
     "sstring",
+    "sstring_async",
     "stat",
+    "stat_async",
     "symlink",
     "touch",
     "walk_gen",
     "wbin",
+    "wbin_async",
     "wbin_gen",
+    "wbin_gen_async",
     "wbytes",
+    "wbytes_async",
     "wbytes_gen",
+    "wbytes_gen_async",
     "wjson",
+    "wjson_async",
     "wstr",
+    "wstr_async",
     "wstring",
+    "wstring_async",
 )
