@@ -903,10 +903,7 @@ async def _do_async(
                 )
                 tf = time()
             except TimeoutError as te:
-                print(dir(_proc))
-                _proc.kill()
                 _proc.terminate()
-
                 raise TimeoutError(
                     str(
                         {
